Credential profiles, field definitions and storage for the ACT host.
Modules
- backend
- expiry
- When a stored credential value is too close to expiry to be served.
- field
- Credential field definitions — what a field name means to this host.
- record
- store
Functions
- write_
private - Atomic write with restrictive permissions: temp file then rename.